========================
Changes in version 1.0.2
========================

.. note::
    This release also includes all applicable changes from the :doc:`0.9.7
    release </changes/0.9.7>`.

Bugfixes
========

* :issue:`258`: Bugfix to a previous, incorrectly applied fix regarding
  `~fabric.operations.local` on Windows platforms.
* :issue:`324`: Update `~fabric.operations.run`/`~fabric.operations.sudo`'s
  ``combine_stderr`` kwarg so that it correctly overrides the global setting in
  all cases. This required changing its default value to ``None``, but the
  default behavior (behaving as if the setting were ``True``) has not changed.
  Thanks to Matthew Woodcraft and Connor Smith for the catch.
* :issue:`337`: Fix logic bug in `~fabric.operations.put` preventing use of
  ``mirror_local_mode``. Thanks to Roman Imankulov for catch & patch.
* :issue:`352` (also :issue:`320`): Seemingly random issues with output lockup
  and input problems (e.g. sudo prompts incorrectly rejecting passwords) appear
  to have been caused by an I/O race condition. This has been fixed. Thanks to
  Max Arnold and Paul Oswald for the detailed reports and to Max for the
  diagnosis and patch.


Documentation
=============

* Updated the API documentation for `~fabric.context_managers.cd` to explicitly
  point users to `~fabric.context_managers.lcd` for modifying local paths.
* Clarified the behavior of `~fabric.contrib.project.rsync_project` re: how
  trailing slashes in ``local_dir`` affect ``remote_dir``. Thanks to Mark
  Merritt for the catch.
